#!/bin/bash
#
### BEGIN INIT INFO
# Provides:          instantafs-networktest
# Required-Start:    $network
# Required-Stop:
# X-Start-Before:    openafs-client libnss-ptdb
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Disables openafs-autostart in case of missing network connection
# Description:       Tests, if the network connection is fine for starting the openafs-client
### END INIT INFO
#
# -- Frank Burkhardt <burk@cbs.mpg.de>  Fri, 08 Feb 2019 11:54:29 +0100

PATH=/sbin:/bin:/usr/sbin:/usr/bin
NAME=instantafs-networktest
DESC='Openafs-Connectivity check'

set -e
LANG=C

# Make sure, systemd takes over
. /lib/lsb/init-functions

[ -r /etc/default/$NAME ] && . /etc/default/$NAME

case "$1" in
	start)
		echo -n "Starting $DESC: $NAME "
		ok=1
		if ! echo "$AFS_AUTOSTART_SWITCH" | /bin/egrep -qi '^(n|no|false|0|)$'; then
			if /usr/bin/instantafs.networktest -R -t "$AFS_START_TIMEOUT"; then
				# Disable AFS-Autostart in case of missing connectivity
				echo -n 'afs_autostart=on '
				sed < /etc/openafs/afs.conf.client 's/\s*AFS_CLIENT\s*=.*/AFS_CLIENT=true/i' > /etc/openafs/afs.conf.client.new
			else
				# Enable it in case of network connectivity being available
				echo -n 'afs_autostart=off '
				sed < /etc/openafs/afs.conf.client 's/\s*AFS_CLIENT\s*=.*/AFS_CLIENT=false/i' > /etc/openafs/afs.conf.client.new
			fi
			mv -f /etc/openafs/afs.conf.client.new /etc/openafs/afs.conf.client
		fi
		echo "."
		;;
	stop)
		echo -n "Stopping $DESC: $NAME"
		echo "."
	;;
	*)
		N=/etc/init.d/$NAME
		echo "Usage: $N {start|stop}" >&2
		exit 1
	;;
esac

exit 0
